yakumo.cinder.v1

Package yakumo :: Package cinder :: Package v1 |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.cinder.v1

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Sub client class for Cinder API v1
    18  """
    19
    20  from . import snapshot
    21  from . import volume
    22  from . import volume_type
    23
    24
    25 -class Client(object):
    26
    27 -    def __init__(self, client, **kwargs):
    28          self.volume = volume.Manager(client, **kwargs)
    29          self.volume_snapshot = snapshot.Manager(client, **kwargs)
    30          self.volume_type = volume_type.Manager(client, **kwargs)
    31
    32          client.volume = self.volume
    33          client.volume_snapshot = self.volume_snapshot
    34          client.volume_type = self.volume_type
    35